pub struct UnixSocketServer { /* private fields */ }Expand description
Unix socket proxy server for a Cloud SQL instance.
Binds a Unix socket on construction, guaranteeing the socket is ready to accept connections once the struct is obtained.
Implementations